pub enum EvictionMode {
Soft,
MaxAge,
MaxSize,
}Expand description
Mode that accounted for evicting a given entry per AUX-024.
When more than one mode would match the same entry, the highest-priority mode wins (in this declaration order).
Variants
Soft
CACHE-022 --soft pass: schema-stale or incomplete
entry.
MaxAge
AUX-023 --max-age pass: well-formed but too old.
MaxSize
AUX-023 --max-size pass: well-formed but oldest among
survivors of the previous passes when the residual
footprint exceeded the bound.