Module key

Module key 

Cache-key type and builder.

CacheKey is the 32-byte content-addressed identity of a task action under a particular set of inputs, predecessor streams, and resolved environment (CACHE-001). CacheKeyBuilder drives the canonical serialisation of CACHE-004..009 through a single Hasher and produces the final CacheKey.

Re-exports

pub use crate::key::components::EnvContribution;
pub use crate::key::components::InputFile;
pub use crate::key::components::PredecessorStreams;
pub use crate::key::prefix::CHAPTER_REVISION;
pub use crate::key::prefix::hash_function_id;
pub use crate::key::prefix::schema_version_prefix;

Modules

components
Canonical serialisation of cache-key components (CACHE-005..009).
prefix
Schema-version prefix (CACHE-003).

Structs

CacheKey
The cache-key identity of a task under a given set of inputs (CACHE-001).
CacheKeyBuilder
Driver for cache-key derivation.
CacheKeyInputs
The full set of inputs to a cache-key derivation (CACHE-004..008).